@@ -31,11 +31,12 @@ void ConfigHandler::setConfig(KScreen::ConfigPtr config)
     KScreen::ConfigMonitor::instance()->addConfig(m_config);
     m_control.reset(new ControlConfig(config));
 
-    m_outputs = new OutputModel(this);
-    connect(m_outputs, &OutputModel::positionChanged, this, &ConfigHandler::checkScreenNormalization);
-    connect(m_outputs, &OutputModel::sizeChanged, this, &ConfigHandler::checkScreenNormalization);
+    m_outputModel = new OutputModel(this);
+    connect(m_outputModel, &OutputModel::positionChanged, this, &ConfigHandler::checkScreenNormalization);
+    connect(m_outputModel, &OutputModel::sizeChanged, this, &ConfigHandler::checkScreenNormalization);
 
-    for (const KScreen::OutputPtr &output : config->outputs()) {
+    const auto outputs = config->outputs();
+    for (const KScreen::OutputPtr &output : outputs) {
         initOutput(output);
     }
     m_lastNormalizedScreenSize = screenSize();
@@ -44,7 +45,7 @@ void ConfigHandler::setConfig(KScreen::ConfigPtr config)
     m_initialRetention = getRetention();
     Q_EMIT retentionChanged();
 
-    connect(m_outputs, &OutputModel::changed, this, [this]() {
+    connect(m_outputModel, &OutputModel::changed, this, [this]() {
         checkNeedsSave();
         Q_EMIT changed();
     });
@@ -65,7 +66,8 @@ void ConfigHandler::resetScale(const KScreen::OutputPtr &output)
     const qreal scale = m_control->getScale(output);
     if (scale > 0) {
         output->setScale(scale);
-        for (auto initialOutput : m_initialConfig->outputs()) {
+        const auto outputs = m_initialConfig->outputs();
+        for (auto initialOutput : outputs) {
             if (initialOutput->id() == output->id()) {
                 initialOutput->setScale(scale);
                 break;
@@ -76,9 +78,11 @@ void ConfigHandler::resetScale(const KScreen::OutputPtr &output)
 
 void ConfigHandler::initOutput(const KScreen::OutputPtr &output)
 {
+    output->setExplicitLogicalSize(config()->logicalSizeForOutput(*output));
+
     if (output->isConnected()) {
         resetScale(output);
-        m_outputs->add(output);
+        m_outputModel->add(output);
     }
     connect(output.data(), &KScreen::Output::isConnectedChanged, this, [this, output]() {
         Q_EMIT outputConnect(output->isConnected());
@@ -94,7 +98,8 @@ void ConfigHandler::updateInitialData()
             return;
         }
         m_initialConfig = qobject_cast<GetConfigOperation *>(op)->config();
-        for (auto output : m_config->outputs()) {
+        const auto outputs = m_config->outputs();
+        for (const auto &output : outputs) {
             resetScale(output);
         }
         m_initialControl.reset(new ControlConfig(m_initialConfig));
@@ -145,8 +150,10 @@ bool ConfigHandler::checkSaveandTestCommon(bool isSaveCheck)
 
             // clang-format off
             if (output->isEnabled()) {
-                bool realScaleChange = output->scale() != config->scale();
-                bool scaleChanged = isSaveCheck ?  realScaleChange : qGuiApp->platformName() == QLatin1String("wayland") ? realScaleChange : false;
+                bool scaleChanged = false;
+                if (isSaveCheck || m_config->supportedFeatures() & KScreen::Config::Feature::PerOutputScaling) {
+                     scaleChanged = output->scale() != config->scale();
+                }
                 if ( output->currentModeId() != config->currentModeId()
                     || output->pos() != config->pos()
                     || scaleChanged
@@ -171,7 +178,8 @@ QSize ConfigHandler::screenSize() const
     int width = 0, height = 0;
     QSize size;
 
-    for (const auto &output : m_config->connectedOutputs()) {
+    const auto connectedOutputs = m_config->connectedOutputs();
+    for (const auto &output : connectedOutputs) {
         if (!output->isPositionable()) {
             continue;
         }
@@ -198,10 +206,9 @@ QSize ConfigHandler::normalizeScreen()
     if (!m_config) {
         return QSize();
     }
-    bool changed = m_outputs->normalizePositions();
 
+    m_outputModel->normalizePositions();
     const auto currentScreenSize = screenSize();
-    changed |= m_lastNormalizedScreenSize != currentScreenSize;
     m_lastNormalizedScreenSize = currentScreenSize;
 
     Q_EMIT screenNormalizationUpdate(true);
@@ -210,7 +217,7 @@ QSize ConfigHandler::normalizeScreen()
 
 void ConfigHandler::checkScreenNormalization()
 {
-    const bool normalized = !m_config || (m_lastNormalizedScreenSize == screenSize() && m_outputs->positionsNormalized());
+    const bool normalized = !m_config || (m_lastNormalizedScreenSize == screenSize() && m_outputModel->positionsNormalized());
 
     Q_EMIT screenNormalizationUpdate(normalized);
 }
@@ -276,7 +283,8 @@ void ConfigHandler::setRetention(int retention)
         return;
     }
     auto ret = static_cast<Retention>(retention);
-    for (const auto &output : m_config->connectedOutputs()) {
+    const auto connectedOutputs = m_config->connectedOutputs();
+    for (const auto &output : connectedOutputs) {
         m_control->setOutputRetention(output, ret);
     }
     checkNeedsSave();
