@@ -30,10 +30,8 @@ public:
     ~OsdManager() override;
 
 public Q_SLOTS:
-    void showOutputIdentifiers();
-    void showOsd(const QString &icon, const QString &text);
     void hideOsd();
-    OsdAction *showActionSelector();
+    KScreen::OsdAction *showActionSelector();
 
 private:
     void slotIdentifyOutputs(KScreen::ConfigOperation *op);
